godimviper

package module
v0.0.0-...-b748623 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 25, 2018 License: MIT Imports: 4 Imported by: 0

README

godim-viper

Version

v0.1 - Alpha Version - Everything may change

Features

  • Adapter for Viper as the configuration loader for Godim

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SetViperConfig

func SetViperConfig(vc *viper.Viper)

SetViperConfig set the Viper configured

func ViperForGodim

func ViperForGodim(key string, val reflect.Value) (res interface{}, err error)

ViperForGodim is a mapper between Viper and Godim for configuration

Types

This section is empty.

Jump to